@@ -41,6 +41,8 @@ Copyright: (C) 1997-2004, Advanced Interfaces Group,
 #include <stdlib.h>
 #include <float.h>
 #include <math.h>
+#include <R.h>
+#include <Rinternals.h>
 
 
 /*
@@ -103,8 +105,8 @@ Copyright: (C) 1997-2004, Advanced Interfaces Group,
 
 #define MALLOC(p, b, s, t) {if ((b) > 0) { \
                             p= (t*)malloc(b); if (!(p)) { \
-                            fprintf(stderr, "gpc malloc failure: %s\n", s); \
-                            exit(0);}} else p= NULL;}
+			    error("gpc malloc failure: %s\n", s); \
+                            }} else p= NULL;}
 
 #define FREE(p)            {if (p) {free(p); (p)= NULL;}}
 
